@@ -5,11 +5,12 @@ from tfs.errors import TfsFormatError
 from tfs.frame import TfsDataFrame, concat
 from tfs.reader import read_tfs
 from tfs.writer import write_tfs
+from tfs.hdf import read_hdf, write_hdf
 
 __title__ = "tfs-pandas"
 __description__ = "Read and write tfs files."
 __url__ = "https://github.com/pylhc/tfs"
-__version__ = "3.0.2"
+__version__ = "3.2.0"
 __author__ = "pylhc"
 __author_email__ = "pylhc@github.com"
 __license__ = "MIT"
@@ -18,4 +19,4 @@ __license__ = "MIT"
 read = read_tfs
 write = write_tfs
 
-__all__ = [concat, read, write, TfsDataFrame, __version__]
+__all__ = [concat, read, write, read_hdf, write_hdf, TfsDataFrame, __version__]
