@@ -72,11 +72,9 @@ def read_tfs(
                 break  # Break to not go over all lines, saves a lot of time on big files
 
     if column_names is None:
-        LOGGER.error(f"No column names in file {tfs_file_path.absolute()}, aborting")
-        raise TfsFormatError("Column names have not been set.")
+        raise TfsFormatError(f"No column names in file {tfs_file_path.absolute()}. File not read.")
     if column_types is None:
-        LOGGER.error(f"No column types in file {tfs_file_path.absolute()}, aborting")
-        raise TfsFormatError("Column types have not been set.")
+        raise TfsFormatError(f"No column types in file {tfs_file_path.absolute()}. File not read.")
 
     LOGGER.debug("Parsing data part of the file")
     # DO NOT use comment=COMMENTS in here, if you do and the symbol is in an element for some
